<?php
/**
 * Plugin Name:       Compress PDF with Cross Service Solutions integration
 * Description:       Effortlessly reduce the size of your PDF files while maintaining quality, making them easier to store, share, and upload without sacrificing readability.
 * Requires at least: 6.6
 * Requires PHP:      7.2
 * Version:           1.0.1
 * Author:            Cross Service Solutions
 * License:           GPL-2.0-or-later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       compress-pdf
 * Domain Path:       /languages
 *
 * @package CreateBlock
 */
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

include_once plugin_dir_path(__FILE__) . 'includes/setting.php';
include_once plugin_dir_path(__FILE__) . 'includes/process-machine.php';
include_once plugin_dir_path(__FILE__) . 'includes/customize.php';
include_once plugin_dir_path(__FILE__) . 'includes/verification.php';

// Include the common components and form builder files
add_action('plugins_loaded', function() {
    if (!function_exists('WP_Filesystem')) {
        require_once ABSPATH . 'wp-admin/includes/file.php';
        WP_Filesystem();
    }
    if (!class_exists('CROSS_SERVICE_SOLUTIONS_CommonComponents')) {
        require_once plugin_dir_path(__FILE__) . 'includes/classes/CommonComponents.php';
    }
    if (!class_exists('CROSS_SERVICE_SOLUTIONS_FormBuilder')) {
        require_once plugin_dir_path(__FILE__) . 'includes/classes/FormBuilder.php';
    }
});

if (!function_exists('cross_service_solutions_enqueue_admin_styles')) {
    function cross_service_solutions_enqueue_admin_styles()
    {
        wp_enqueue_style('cross-service-solutions-admin-style', plugin_dir_url(__FILE__) . 'includes/styles/setting.css', array(), '1.0.0', 'all');
    }
    add_action('admin_enqueue_scripts', 'cross_service_solutions_enqueue_admin_styles');
}

function cross_service_solutions_register_compress_pdf_shortcode() {
    ob_start();
    include plugin_dir_url( __FILE__ ) . 'src/render.php';
    return ob_get_clean();
}
add_shortcode( 'cross_service_solutions_compress_pdf_widget', 'cross_service_solutions_register_compress_pdf_shortcode' );

// Hook to run when the plugin is activated
function cross_service_solutions_compress_pdf_activate() {
    $active_plugins = get_option('cross_service_solutions_all_activate_plugins', []);

    if (!in_array('compress_pdf', $active_plugins)) {
        $active_plugins[] = 'compress_pdf';
    }

    update_option('cross_service_solutions_all_activate_plugins', $active_plugins);
}
register_activation_hook(__FILE__, 'cross_service_solutions_compress_pdf_activate');

// Hook to run when the plugin is deactivated
function cross_service_solutions_compress_pdf_deactivate() {
    $active_plugins = get_option('cross_service_solutions_all_activate_plugins', []);

    if (($key = array_search('compress_pdf', $active_plugins)) !== false) {
        unset($active_plugins[$key]);
    }

    if (empty($active_plugins)) {
        delete_option('cross_service_solutions_all_activate_plugins');
        delete_option('cross_service_solutions_api_key');
    } else {
        update_option('cross_service_solutions_all_activate_plugins', array_values($active_plugins));
    }
}
register_deactivation_hook(__FILE__, 'cross_service_solutions_compress_pdf_deactivate');

/**
 * Registers the block using the metadata loaded from the `block.json` file.
 * Behind the scenes, it registers also all assets so they can be enqueued
 * through the block editor in the corresponding context.
 *
 * @see https://developer.wordpress.org/reference/functions/register_block_type/
 */
function cross_service_solutions_compress_pdf_block_init() {

    // Load MO files for PHP.
	load_plugin_textdomain( 'compress-pdf', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' ); 

    register_block_type_from_metadata( __DIR__ . '/build' ,[
		'title'           => _x( 'Compress Pdf', 'block title', 'compress-pdf' ),
		'description'     => _x( 'Effortlessly reduce the size of your PDF files while maintaining quality, making them easier to store, share, and upload without sacrificing readability.', 'block description', 'compress-pdf' ),
	] );

    // Load JSON files for JS - this is necessary if using a custom languages path!!
    $script_handle = generate_block_asset_handle( 'create-block/compress-pdf', 'editorScript' );
    wp_set_script_translations( $script_handle, 'compress-pdf', plugin_dir_path( __FILE__ ) . 'languages' );
}
add_action( 'init', 'cross_service_solutions_compress_pdf_block_init' );

function cross_service_solutions_compress_pdf_localize_script() {
    // Localize the script registered by the viewScript in block.json
    wp_localize_script('create-block-compress-pdf-view-script', 'wpApiSettingsCompressPDF', array(
        'root' => esc_url_raw(rest_url()),
        'compressPDFNonce' => wp_create_nonce('compress_pdf_form_nonce_action'),
    ));
}
add_action('enqueue_block_assets', 'cross_service_solutions_compress_pdf_localize_script');

function cross_service_solutions_compress_pdf_load_custom_textdomain( $mofile, $domain ) {
    if ('compress-pdf' === $domain) {
        $locale = apply_filters( 'plugin_locale', determine_locale(), $domain );
        $mofile = WP_PLUGIN_DIR . '/' . dirname( plugin_basename( __FILE__ ) ) . '/languages/' . $domain . '-' . $locale . '.mo';
    }
    return $mofile;
}
add_filter( 'load_textdomain_mofile', 'cross_service_solutions_compress_pdf_load_custom_textdomain', 10, 2 );

function cross_service_solutions_compress_pdf_enqueue_cdn_script() {
    wp_enqueue_style( 'ion-range-slider-css',  plugin_dir_url(__FILE__) . 'includes/styles/ion.rangeSlider.min.css', array(), '2.3.1', 'all' );
    wp_enqueue_script( 'rangeslider-cdn', plugin_dir_url(__FILE__) . 'includes/scripts/rangeSlider.min.js', array(), '1.0.0', true );
}
add_action( 'wp_enqueue_scripts', 'cross_service_solutions_compress_pdf_enqueue_cdn_script' );
add_action('enqueue_block_editor_assets', 'cross_service_solutions_compress_pdf_enqueue_cdn_script');

function cross_service_solutions_compress_pdf_enqueue_editor_style() {
    add_editor_style( plugin_dir_url(__FILE__) . 'includes/styles/ion.rangeSlider.min.css');
}
add_action('admin_init', 'cross_service_solutions_compress_pdf_enqueue_editor_style');
