<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class CROSS_SERVICE_SOLUTIONS_CommonComponents {
    // Text Input Component
    public static function text_input_component($name, $label, $id = '', $required = true, $hint = '', $placeholder = '', $type = 'text') {
        ob_start();
        ?>
        <label class="solution__label">
            <span><?php echo esc_html($label); ?></span>
            <input type="<?php echo esc_attr($type); ?>" 
                name="<?php echo esc_attr($name); ?>" 
                <?php if ($id) echo 'id="' . esc_attr($id) . '"'; ?>
                placeholder="<?php echo esc_attr($placeholder); ?>" 
                class="solution__input" 
                <?php echo $required ? 'required' : ''; ?> />
            <?php if ($hint): ?>
                <span class="solution__hint"><?php echo esc_html($hint); ?></span>
            <?php endif; ?>
        </label>
        <?php
        return ob_get_clean();
    }

    // Text Area Input Component
    public static function textarea_input_component($name, $label, $id = '', $required = true, $hint = '', $placeholder = '') {
        ob_start();
        ?>
        <label class="solution__label">
            <span><?php echo esc_html($label); ?></span>
            <textarea name="<?php echo esc_attr($name); ?>" 
                placeholder="<?php echo esc_attr($placeholder); ?>" 
                <?php if ($id) echo 'id="' . esc_attr($id) . '"'; ?>
                class="solution__textarea" 
                <?php echo $required ? 'required' : ''; ?>
                ></textarea>
            <?php if ($hint): ?>
                <span class="solution__hint"><?php echo esc_html($hint); ?></span>
            <?php endif; ?>
        </label>
        <?php
        return ob_get_clean();
    }

    // Number Input Component
    public static function number_input_component($name, $label, $id = '', $min = null, $max = null, $default = '', $required = true, $hint = '', $use_slider = false, $placeholder = '') {
        ob_start();
        ?>
        <label class="solution__label">
            <span><?php echo esc_html($label); ?></span>
            <?php
            $input_class = 'solution__input';
            if ($use_slider && $min !== null && $max !== null) {
                $input_class .= ' solution__range-linked';
            }
            ?>
            <input type="number" 
                   name="<?php echo esc_attr($name); ?>" 
                   <?php if ($id) echo 'id="' . esc_attr($id) . '"'; ?>
                   class="<?php echo esc_attr($input_class); ?>" 
                   value="<?php echo esc_attr($default); ?>"
                   placeholder="<?php echo esc_attr($placeholder); ?>" 
                   <?php echo ($min !== null) ? 'min="' . esc_attr($min) . '"' : ''; ?>
                   <?php echo ($max !== null) ? 'max="' . esc_attr($max) . '"' : ''; ?>
                   <?php echo $required ? 'required' : ''; ?> 
                   />
            <?php if ($hint): ?>
                <span class="solution__hint"><?php echo esc_html($hint); ?></span>
            <?php endif; ?>
        </label>
        <?php
        return ob_get_clean();
    }

    // File Input Component
    public static function file_input_component($name, $label, $id = '',$multiple = false, $required = true, $hint = '') {
        ob_start();
        ?>
        <label class="solution__label">
            <span><?php echo esc_html($label); ?></span>
            <input type="file" name="<?php echo esc_attr($name); ?>" <?php if ($id) echo 'id="' . esc_attr($id) . '"'; ?>class="solution__file-input" <?php echo $multiple ? 'multiple' : ''; ?> <?php echo $required ? 'required' : ''; ?> />
            <?php if ($hint): ?>
                <span class="solution__hint"><?php echo esc_html($hint); ?></span>
            <?php endif; ?>
        </label>
        <div class="solution__file-preview"></div>
        <?php
        return ob_get_clean();
    }

    // Single Select Dropdown Component
    public static function single_select_component($name, $label, $options = [], $id = '', $required = true, $hint = '', $default_option = []) {
        ob_start();
        ?>
        <div class="solution__select">
            <span class="solution__label"><?php echo esc_html($label); ?></span>
            <select name="<?php echo esc_attr($name); ?>" <?php if ($id) echo 'id="' . esc_attr($id) . '"'; ?>class="solution__select-input" <?php echo $required ? 'required' : ''; ?>>
                <?php if (empty($default_option) || !isset($default_option['display'], $default_option['value'])): ?>
                    <option value="" disabled hidden selected>Please select</option>
                <?php endif; ?>
    
                <?php foreach ($options as $option): ?>
                    <option value="<?php echo esc_attr($option['value']); ?>" 
                        <?php echo ($default_option['value'] === $option['value']) ? 'selected' : ''; ?>>
                        <?php echo esc_html($option['display']); ?>
                    </option>
                <?php endforeach; ?>
    
            </select>
            <?php if ($hint): ?>
                <span class="solution__hint"><?php echo esc_html($hint); ?></span>
            <?php endif; ?>
        </div>
        <?php
        return ob_get_clean();
    }  

    // Multiple Select Dropdown Component
    public static function multiple_select_component($name, $label, $options, $id = '', $required = true, $hint = '') {    
        ob_start();
        ?>
        <div class="solution__dropdown" id="<?php echo esc_attr($id); ?>">
            <button type="button" class="solution__btn solution__dropdown-button"><?php echo esc_html($label); ?></button>
            <div class="solution__dropdown-content" <?php echo $required ? 'required' : ''; ?>>
                <?php foreach ($options as $option): ?>
                    <label>
                        <input type="checkbox" name="<?php echo esc_attr($name); ?>[]" value="<?php echo esc_attr($option); ?>">
                        <?php echo esc_html($option); ?>
                    </label>
                <?php endforeach; ?>
            </div>
            <?php if ($hint): ?>
                <span class="solution__hint"><?php echo esc_html($hint); ?></span>
            <?php endif; ?>
        </div>
        <?php
        return ob_get_clean();
    }

    // Button Input Component
    public static function button_input_component($text, $type = 'submit', $name = '', $id = '') {
        ob_start();
        ?>
        <button type="<?php echo esc_attr($type); ?>" name="<?php echo esc_attr($name); ?>" <?php if ($id) echo 'id="' . esc_attr($id) . '"'; ?>class="solution__btn">
            <?php echo esc_html($text); ?>
        </button>
        <?php
        return ob_get_clean();
    }

    // Loading Component (no hint needed here)
    public static function loading_component($id = '') {
        ob_start();
        ?>
        <div id="loadingSection_<?php echo esc_attr($id); ?>" class="solution__loading-section">
            <div class="solution__loading-container">
                <span class="solution__text">Loading</span>
                <div class="solution__dot"></div>
                <div class="solution__dot"></div>
                <div class="solution__dot"></div>
            </div>
        </div>
        <?php
        return ob_get_clean();
    }
}
?>
