<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class CROSS_SERVICE_SOLUTIONS_FormBuilder {
    private $form_id;
    private $elements = [];
    public $allowed_html = array(
        'div' => array(
            'class' => array(), 
            'id'    => array(),
        ),
        'input' => array(
            'type'      => array(), 
            'class'     => array(), 
            'name'      => array(), 
            'value'     => array(), 
            'id'        => array(),
            'required'  => array(),
            'multiple' => array(),
            'placeholder' => array(),
            'min' => array(),
            'max' => array()
        ),
        'textarea' => array(
            'class'     => array(),
            'name'      => array(),
            'id'        => array(),
            'required'  => array(),
            'placeholder' => array(),
        ),
        'select' => array(
            'class'     => array(),
            'name'      => array(),
            'id'        => array(),
            'required'  => array(),
            'multiple'  => array(),
        ),
        'option' => array(
            'value'     => array(),
            'disabled'  => array(), 
            'selected'  => array(), 
            'hidden'    => array(), 
            'label'     => array(), 
        ),
        'label' => array(
            'class' => array(), 
            'name'  => array(), 
        ),
        'span' => array(
            'class' => array(), 
            'id'    => array() 
        ),
        'button' => array(
            'type'      => array(), 
            'class'     => array(), 
            'name'      => array(), 
            'value'     => array(), 
            'id'        => array(),
            'required'  => array(),
        )
    );

    public function __construct($form_id) {
        $this->form_id = esc_attr($form_id);
    }

    public function text_input_component($name, $label, $id = '', $required = true, $hint = '', $placeholder = '', $type = 'text') {
        $this->elements[] = CROSS_SERVICE_SOLUTIONS_CommonComponents::text_input_component($name, $label, $id, $required, $hint, $placeholder, $type);
        return $this;
    }

    public function textarea_input_component($name, $label, $id = '', $required = true, $hint = '', $placeholder = '') {
        $this->elements[] = CROSS_SERVICE_SOLUTIONS_CommonComponents::textarea_input_component($name, $label, $id, $required, $hint, $placeholder);
        return $this;
    }

    public function number_input_component($name, $label, $id = '', $min = null, $max = null, $default = '', $required = true, $hint = '', $use_slider = false, $placeholder = '') {
        $this->elements[] = CROSS_SERVICE_SOLUTIONS_CommonComponents::number_input_component($name, $label, $id, $min, $max, $default, $required, $hint, $use_slider, $placeholder);
        return $this;
    }

    public function file_input_component($name, $label, $id = '', $multiple = false, $required = true, $hint = '') {
        $this->elements[] = CROSS_SERVICE_SOLUTIONS_CommonComponents::file_input_component($name, $label, $id, $multiple, $required, $hint);
        return $this;
    }

    public function single_select_component($name, $label, $options, $id = '', $required = true, $hint = '', $default_option= []) {
        $this->elements[] = CROSS_SERVICE_SOLUTIONS_CommonComponents::single_select_component($name, $label, $options, $id, $required, $hint, $default_option);
        return $this;
    }

    public function multiple_select_component($name, $label, $options, $id = '', $required = true, $hint = '') {
        $this->elements[] = CROSS_SERVICE_SOLUTIONS_CommonComponents::multiple_select_component($name, $label, $options, $id, $required, $hint);
        return $this;
    }

    public function button_input_component($text, $type = 'submit', $name = '', $id = '') {
        $button_html = CROSS_SERVICE_SOLUTIONS_CommonComponents::button_input_component($text, $type, $name, $id);
        $this->elements[] = $button_html;
        return $this;
    }    

    public function group_elements(...$elements) {
        $row_html = '<div class="solution__group">';
        foreach ($elements as $element) {
            $row_html .= wp_kses($element, $this->allowed_html);
        }
        $row_html .= '</div>';
        $this->elements[] = $row_html;
        return $this;
    }

    public function build() {
        ob_start();
        ?>
        <form id="<?php echo esc_attr($this->form_id); ?>" class="solution__form" autocomplete="off"> 
            <?php foreach ($this->elements as $element) {
                echo wp_kses($element, $this->allowed_html); 
            } ?>
        </form>
        <?php
        return ob_get_clean();
    }
}
?>
