<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// Register REST API endpoints
function cross_service_solutions_compress_pdf_register_rest_api() {
    register_rest_route('compress-pdf/v1', '/test', array(
        'methods' => 'GET',
        'callback' => 'cross_service_solutions_test_compress_pdf_api_callback',
        'permission_callback' => '__return_true',
    ));
    
    register_rest_route('compress-pdf/v1', '/send-data', array(
        'methods' => 'POST',
        'callback' => 'cross_service_solutions_compress_pdf_on_submit',
        'permission_callback' => '__return_true',
    ));
    register_rest_route('compress-pdf/v1', '/status/(?P<id>\d+)', array(
        'methods' => 'GET',
        'callback' => 'cross_service_solutions_compress_pdf_check_status',
        'permission_callback' => '__return_true',
    ));
}
add_action('rest_api_init', 'cross_service_solutions_compress_pdf_register_rest_api');

function cross_service_solutions_test_compress_pdf_api_callback() {
    return new WP_REST_Response('Test API is working', 200);
}
 
// Handle form submission, then initiate processing
function cross_service_solutions_compress_pdf_on_submit($request) {
    // Check if nonce is set and valid
    if (!isset($request['compressPDFFormNonce']) || 
        !wp_verify_nonce($request['compressPDFFormNonce'], 'compress_pdf_form_nonce_action')) {
        return new WP_Error('nonce_invalid', 'Nonce verification failed', array('status' => 403, 'message' => $request['compressPDFFormNonce']));
    } 

    $api_key = esc_attr(get_option('cross_service_solutions_api_key'));

    // Check if files and other necessary fields are present
    if (empty($_FILES['file']) || empty($_POST['dpi']) || empty($_POST['imageQuality'])) {
        return new WP_Error('missing_data', 'Files are missing', array('status' => 400));
    }

    $dpi = trim(sanitize_text_field(wp_unslash($_POST['dpi'])));
    $image_quality = trim(sanitize_text_field(wp_unslash($_POST['imageQuality'])));

    // Prepare boundary for multipart data
    $boundary = '----WebKitFormBoundary7MA4YWxkTrZu0gW';
    $body = "--$boundary\r\n";
    
    // Append non-file fields to the body
    $body .= "Content-Disposition: form-data; name=\"dpi\"\r\n\r\n" . $dpi . "\r\n";
    $body .= "--$boundary\r\n";
    $body .= "Content-Disposition: form-data; name=\"imageQuality\"\r\n\r\n" . $image_quality . "\r\n";

    // Loop through each file and append it to the body
    if (!empty($_FILES['file']['name'])) {
        $files_name = array_map( 'sanitize_file_name', $_FILES['file']['name'] );
        
        foreach ($files_name as $index => $name) {
            $file = array(
                'name'     => $name,
                'type'     => isset($_FILES['file']['type'][$index]) ? sanitize_mime_type($_FILES['file']['type'][$index]) : '',
                'tmp_name' => isset($_FILES['file']['tmp_name'][$index]) ? sanitize_text_field($_FILES['file']['tmp_name'][$index]) : '',
                'error'    => isset($_FILES['file']['error'][$index]) ? intval($_FILES['file']['error'][$index]) : 0,
                'size'     => isset($_FILES['file']['size'][$index]) ? intval($_FILES['file']['size'][$index]) : 0,
            );

            // Check for file upload errors
            if ($file['error'] !== UPLOAD_ERR_OK) {
                return new WP_Error('file_upload_error', 'File upload error: ' . $file['error'], array('status' => 500));
            }

            // Get file contents using WP_Filesystem
            global $wp_filesystem;
            $file_contents = $wp_filesystem->get_contents($file['tmp_name']);

            if ($file_contents === false) {
                return new WP_Error('file_read_error', 'Unable to read uploaded file', array('status' => 500));
            }

            // Append each file to the multipart body
            $body .= "--$boundary\r\n";
            $body .= "Content-Disposition: form-data; name=\"file[]\"; filename=\"{$file['name']}\"\r\n";
            $body .= "Content-Type: {$file['type']}\r\n\r\n";
            $body .= $file_contents . "\r\n";
        }
    }
    $body .= "--$boundary--";

    // Set up the headers with authorization
    $headers = array(
        'Authorization' => 'Bearer ' . $api_key,
        'Content-Type' => 'multipart/form-data; boundary=' . $boundary,
    );

    // Make the API request
    $response = wp_remote_post('https://api.process-machine-stage.com/solutions/solutions/wordpress/29', array(
        'method'    => 'POST',
        'body'      => $body,
        'headers'   => $headers,
    ));

    if (is_wp_error($response)) {
        return new WP_Error('api_error', 'Request failed: ' . $response->get_error_message(), array('status' => 500));
    }

    $response_code = wp_remote_retrieve_response_code($response);
    $response_body = wp_remote_retrieve_body($response);

    if ($response_code !== 200 && $response_code !== 201) {
        return new WP_Error('api_error', 'API request failed with status code ' . $response_code, array('status' => $response_code));
    }

    $response_data = json_decode($response_body, true);

    return new WP_REST_Response(array(
        'id'      => $response_data['id'],
        'name'    => $response_data['name'],
        'status'  => $response_data['status'],
        'steps'   => $response_data['steps'] ?? [],
        'output'  => $response_data['output'] ?? null,
    ), 200);
}

// Check status of processing task
function cross_service_solutions_compress_pdf_check_status($request) {
    $nonce = $request->get_header('X-WP-Nonce');
    if (!$nonce || !wp_verify_nonce($nonce, 'compress_pdf_form_nonce_action')) {
        return new WP_Error('nonce_invalid', 'Nonce verification failed', array(
            'status' => 403,
            'message' => 'The provided nonce is invalid or expired. Please refresh and try again.' 
        ));
    } 

    $api_key = esc_attr(get_option('cross_service_solutions_api_key'));
    $id = sanitize_text_field($request['id']);

    $response = wp_remote_get("https://api.process-machine-stage.com/solutions/solutions/wordpress/{$id}", array(
        'headers' => array(
            'Authorization' => 'Bearer ' . $api_key
        ),
    ));

    if (is_wp_error($response)) {
        return new WP_Error('api_request_failed', 'Failed to retrieve process status', array('status' => 500));
    }

    $response_body = wp_remote_retrieve_body($response);
    return new WP_REST_Response(json_decode($response_body), 200);
}
