<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// Centralized settings template in main plugin
if (!function_exists('cross_service_solutions_settings_page_template')) {
    function cross_service_solutions_settings_page_template() {
        // Create the settings page if it doesn't already exist
        add_menu_page(
            __('XSS Settings', 'compress-pdf'),
            __('XSS Settings', 'compress-pdf'),
            'manage_options',
            'cross-service-solutions-settings',
            'cross_service_solutions_settings_page_render'
        );
    }
    add_action('admin_menu', 'cross_service_solutions_settings_page_template');

    function cross_service_solutions_settings_page_render() {
        $api_key = esc_attr(get_option('cross_service_solutions_api_key'));
        $show_provider = esc_attr(get_option('cross_service_solutions_show_provider', 'no'));
        ?>
        <div class='solution-setting-notification-box'>
            <?php
                settings_errors('cross_service_solutions_api_key');
            ?>
        </div>
        <div class="solution-setting-container">
            <div class="solution-setting-login-wrapper">
                <div class="solution-setting-login-name">
                    <h1><?php esc_html_e('Enter Your API Key', 'compress-pdf'); ?></h1>
                </div>

                <form method="post" action="options.php">
                    <?php
                    settings_fields('cross_service_solutions_plugin_settings');
                    do_settings_sections('cross_service_solutions_plugin_settings');
                    ?>
                    <div class="solution-setting-form-group">
                        <div class="solution-setting-inputs">
                            <input type="password" id="cross-service-solutions-license-key" name="cross_service_solutions_api_key" placeholder="<?php esc_html_e('Enter Your API Key', 'compress-pdf'); ?>" value="<?php echo esc_attr($api_key); ?>">                       
                            <div class="solution-setting-underline-input"></div>
                        </div>
                        <div class="solution-setting-checkbox">
                            <input type="checkbox" id="cross-service-solutions-show-password">
                            <label for="cross-service-solutions-show-password" ><?php esc_html_e('Show API Key', 'compress-pdf'); ?></label>
                        </div>
                        <div class="solution-setting-checkbox">
                            <input type="checkbox" id="cross-service-solutions-show-provider" name="cross_service_solutions_show_provider" value="yes" <?php checked($show_provider, 'yes'); ?>>
                            <label for="cross-service-solutions-show-provider"><?php esc_html_e('Show "Provided by" info', 'compress-pdf'); ?></label>
                        </div>
                    </div>
                    <div class="pdf-submit-button">
                        <?php submit_button(); ?>
                    </div>
                </form>
                <div class="solution-setting-text-sm">
                    <?php esc_html_e("Don't have an API Key?", 'compress-pdf'); ?>
                    <a href="<?php echo esc_url(__('https://login.xss-cross-service-solutions.com/login', 'compress-pdf')); ?>" target="_blank">
                        <?php esc_html_e('Go to xss cross service solutions to register and get your API Key!', 'compress-pdf'); ?>
                    </a>
                </div>
            </div>
        </div>
        <?php
    }
}

if (!function_exists('cross_service_solutions_register_settings')){
    function cross_service_solutions_register_settings() {
        register_setting('cross_service_solutions_plugin_settings', 'cross_service_solutions_api_key', 'cross_service_solutions_verify_api_key');
        register_setting('cross_service_solutions_plugin_settings', 'cross_service_solutions_show_provider', 'cross_service_solutions_sanitize_show_provider');
    }
    add_action('admin_init', 'cross_service_solutions_register_settings');
}

if (!function_exists('cross_service_solutions_enqueue_password_toggle_script')) {
    function cross_service_solutions_enqueue_password_toggle_script() {
        wp_register_script(
            'solution-password-toggle', // Handle name
            plugin_dir_url(__FILE__) . 'scripts/password-toggle.js', 
            array(), // No dependencies
            '1.0.0', 
            true 
        );
        
        wp_enqueue_script('solution-password-toggle'); 
    }
    add_action('admin_enqueue_scripts', 'cross_service_solutions_enqueue_password_toggle_script');
}

// Sanitization function for the 'cross_service_solutions_show_provider' checkbox
if (!function_exists('cross_service_solutions_sanitize_show_provider')) {
    function cross_service_solutions_sanitize_show_provider($input) {
        $show_provider = sanitize_text_field($input);
        // Ensure the value is either 'yes' or 'no'
        return ( $show_provider === 'yes' ) ? 'yes' : 'no';
    }
}

// Function to sanitization and verify the API Key during form submission
if (!function_exists('cross_service_solutions_verify_api_key')) {
    function cross_service_solutions_verify_api_key($api_key) {
        // Sanitize the API Key by stripping out unwanted characters
        $api_key = sanitize_text_field($api_key);

        // Check if the key is empty (bypass validation)
        if (empty($api_key)) {
            return $api_key;
        }

        // Pass the actual API Key to the validation function
        $license_data = cross_service_solutions_check_api_key($api_key);

        if ($license_data) {
            // If valid, display a success message and return the API Key
            add_settings_error('cross_service_solutions_api_key', 'valid_license', __('Welcome ', 'compress-pdf') . $license_data->name, 'success');
        } else {
            // If invalid, return the key with an error message
            add_settings_error('cross_service_solutions_api_key', 'invalid_license', __('Invalid API Key', 'compress-pdf'), 'error');
        }

        return $api_key;
    }
}
