<?php
/**
 * @see https://github.com/WordPress/gutenberg/blob/trunk/docs/reference-guides/block-api/block-metadata.md#render
 */
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

$form_id = uniqid('form_');
$show_provider = get_option('cross_service_solutions_show_provider', 'no');
$formBuilder = new CROSS_SERVICE_SOLUTIONS_FormBuilder($form_id);
$allowed_html = array(
    'div' => array(
        'class' => array(), 
        'id'    => array(),
    ),
    'input' => array(
        'type'      => array(), 
        'class'     => array(), 
        'name'      => array(), 
        'value'     => array(), 
        'id'        => array(),
        'required'  => array(),
        'multiple' => array(),
        'min' => array(),
        'max' => array()
    ),
    'textarea' => array(
        'class'     => array(),
        'name'      => array(),
        'id'        => array(),
        'required'  => array(),
    ),
    'select' => array(
        'class'     => array(),
        'name'      => array(),
        'id'        => array(),
        'required'  => array(),
        'multiple'  => array(),
    ),
    'option' => array(
        'value'     => array(),
        'disabled'  => array(),
        'selected'  => array(), 
        'hidden'    => array(), 
        'label'     => array(),
    ),
    'label' => array(
        'class' => array(), 
        'name'  => array(), 
    ),
    'span' => array(
        'class' => array(), 
        'id'    => array() 
    ),
    'button' => array(
        'type'  => array(), 
        'class' => array(), 
        'name'  => array(), 
        'value' => array(), 
        'id'    => array(), 
        'required'  => array(),
    ),
    'form' => array(
        'class' => array(), 
        'name'  => array(), 
        'value' => array(), 
        'id'    => array(),
        'autocomplete' => array(),
    ),
);

// Create the form
$form_html = $formBuilder
    ->file_input_component('file', __('File:', 'compress-pdf'), '')
    ->number_input_component('dpi', __('DPI:', 'compress-pdf'), '', 72, 300, 144, true, __('Dots per inch from 72 to 300. Smaller value reduces size of PDF File but also quality.', 'compress-pdf'), true)
    ->number_input_component('image-quality', __('Image Quality:', 'compress-pdf'), '', 1, 100, 75, true, __('Values in % from 0 to 100. Smaller value reduces size of PDF File but also the quality.', 'compress-pdf'), true)
    ->button_input_component(__('Submit', 'compress-pdf'), 'submit')
    ->build();
?>

<div class="solution__compress-pdf">
    <div class="solution__container-wrapper">
        <div class="solution__container">
            <div class="solution__header"><?php esc_html_e('Compress PDF', 'compress-pdf'); ?></div>
            <div class="solution__content">
                <?php 
                echo wp_kses($form_html, $allowed_html);
                ?>

                <!-- Loading Message -->
                <?php
                echo wp_kses(CROSS_SERVICE_SOLUTIONS_CommonComponents::loading_component($form_id), $allowed_html);
                ?>

                <!-- Download Section -->
                <div id="downloadSection_<?php echo esc_attr($form_id); ?>" class="solution__download-section" style="display: none;">
                    <div class="solution__download-container">
                        <span><?php esc_html_e('Your files are ready to download', 'compress-pdf'); ?></span>
                        <div id="downloadFilesContainer_<?php echo esc_attr($form_id); ?>" class="solution__download-file-container"></div>
                    </div>
                    <button id="restartDownloadBtn_<?php echo esc_attr($form_id); ?>" type="button" class="solution__btn">
                        <div class="dashicons dashicons-image-rotate"></div>
                        <span><?php esc_html_e('Restart', 'compress-pdf'); ?></span>
                    </button>
                </div>

                <!-- Result Section -->
                <div id="errorSection_<?php echo esc_attr($form_id); ?>" class="solution__error-section" style="display: none;">
                    <div id="resultMessage_<?php echo esc_attr($form_id); ?>" class="solution__result-message"></div>
                    <button id="restartErrorBtn_<?php echo esc_attr($form_id); ?>" type="button" class="solution__btn">
                        <div class="dashicons dashicons-image-rotate"></div>
                        <span><?php esc_html_e('Restart', 'compress-pdf'); ?></span>
                    </button>
                </div>
            </div>

            <div id="widgetlink">
                <?php if ($show_provider === 'yes') : ?>
                    <div class="solution__provided-text">
                        <div>
                            <span>
                                <?php 
                                    echo esc_html__('*This widget is provided by PDF24. Get your own widget to enable your visitors to:', 'compress-pdf'); 
                                ?>
                            </span>
                            <span>
                                <?php 
                                    printf(
                                        '<a class="solution__link" target="_blank" href="%s">%s</a>',
                                        esc_url(__('https://tools.pdf24.org/en/compress-pdf', 'compress-pdf')),
                                        esc_html__('compress pdf', 'compress-pdf')
                                    ); 
                                ?>
                            </span>
                            <span>
                                <?php 
                                    echo esc_html__('on your website', 'compress-pdf'); 
                                ?>
                            </span>
                        </div>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>
